@@ -27,7 +27,7 @@ from tiddlyweb.store import (NoBagError, NoRecipeError, NoTiddlerError,
 from tiddlyweb.stores import StorageInterface
 from tiddlyweb.util import binary_tiddler
 
-__version__ = '3.0.6'
+__version__ = '3.0.7'
 
 #logging.basicConfig()
 #logging.getLogger('sqlalchemy.engine').setLevel(logging.INFO)
@@ -480,10 +480,9 @@ class Store(StorageInterface):
     def tiddler_delete(self, tiddler):
         try:
             try:
-                stiddlers = (self.session.query(sTiddler).
+                rows = (self.session.query(sTiddler).
                         filter(sTiddler.title == tiddler.title).
-                        filter(sTiddler.bag == tiddler.bag))
-                rows = self.session.delete(stiddlers.one())
+                        filter(sTiddler.bag == tiddler.bag).delete())
                 if rows == 0:
                     raise NoResultFound
                 self.session.commit()
@@ -746,9 +745,15 @@ class Store(StorageInterface):
 
         self.session.flush()
 
-        text = sText(tiddler.text)
-        text.revision_number = srevision.number
-        self.session.add(text)
+        # Do text inserts "raw" so we can use DELAYED
+        if 'mysql_engine' in sText.__table__.kwargs:
+            prefix = 'DELAYED'
+        else:
+            prefix = ''
+        text_insert = (sText.__table__.insert()
+                .prefix_with(prefix).values(text=tiddler.text,
+                    revision_number=srevision.number))
+        self.session.execute(text_insert)
 
         for tag in set(tiddler.tags):
             stag = sTag(tag)
